==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Wyczyść log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Czy na pewno chcesz wyczyścić dziennik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 tydzień</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miesiąc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miesiące</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksport</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Eksportowanie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksport powiódł się</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Błąd eksportu</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksportuj plik</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Okres:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista aplikacji:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ wydarzenia:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akcja:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa Użytkownika:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rekord rozruchowy</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zamknij rekord</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rekord logowania</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Plik dziennika jest pusty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Przeglądarka dziennika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Przeglądarka dzienników to przydatne narzędzie do przeglądania dzienników systemowych.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akcja</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ wydarzenia</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data i godzina:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informacje:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Zero</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Dziennik systemu</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Dziennik jądra</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Dziennik rozruchu</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Dziennik Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Dziennik Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Dziennik aplikacji</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Zdarzenie zamknięcia systemu</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w Menedżerze plików</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Wyczyść dziennik</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Czy na pewno chcesz wyczyścić dziennik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 tydzień</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miesiąc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miesiące</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksportuj</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Eksportowanie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksport zakończony pomyślnie</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Błąd eksportu</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksportuj plik</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Okres:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista aplikacji:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ wydarzenia:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akcja:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa Użytkownika:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Wpis uruchomienia systemu</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Wpis zamknięcia systemu</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Wpis logowania do systemu</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Plik dziennika jest pusty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Przeglądarka dziennika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Przeglądarka dzienników to przydatne narzędzie do przeglądania dzienników systemowych.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akcja</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ wydarzenia</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data i godzina:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informacje:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Zero</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Dziennik systemu</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Dziennik jądra</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Dziennik rozruchu</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Dziennik Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Dziennik Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Dziennik aplikacji</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Zdarzenie zamknięcia systemu</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Częstotliwość odświeżania</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sekund</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 minuta</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nie odświeżaj</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportuj wszystko</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Dziennik systemowy</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Odśwież teraz</translation>
    </message>
</context>
</TS>
